# provision_py_proj

Provision an empty Python package.

Create empty Package with following structure:

    test_pkg
    ├── bin
    │   └── test_pkg
    ├── .gitignore
    ├── LICENSE.txt
    ├── MANIFEST.in
    ├── README.md
    ├── requirements.txt
    ├── setup.py
    └── test_pkg
        ├── __init__.py
        └── test
            └── __init__.py


# Installation

pip3 install provision_py_proj

# Usage

provision_py_proj --help

